@@ -251,6 +251,8 @@ if ($ret === FALSE) {
 /* 桼̾Ǽ */
 $user = $env['loginuser'];
 $userdn = $env['user_selfdn'];
+$trans = "";
+$save = "";
 
 /* 桼μ */
 $ret = get_userdata ($userdn);
@@ -274,11 +276,13 @@ if (isset($_POST['modify'])) {
     $mail = $ldapdata[0]['mail'][0];
     $passwd = $_POST['passwd1'];
     $repasswd = $_POST['passwd2'];
-    $trans = $_POST['trans'];
-    if (isset($_POST['save'])) { 
-        $save = $_POST['save'];
-    } else {
-        $save = NULL;
+    if (isset($_POST['trans'])) {
+        $trans = $_POST['trans'];
+        if (isset($_POST['save'])) { 
+            $save = $_POST['save'];
+        } else {
+            $save = NULL;
+        }
     }
 
     /* ϥǡΥå */
@@ -316,7 +320,9 @@ $save_mail_check = "";
 $unsave_mail_check = "";
 if ($mode == MODE_POSTDATA) {
     /* ⡼ɡʹܥ󤬲줿 */
-    $trans = escape_html($_POST['trans']);
+    if (isset($_POST['trans'])) {
+        $trans = escape_html($_POST['trans']);
+    }
     if (isset($_POST['save']) && $_POST['save'] == "0") {
         $save_mail_check = "checked";
     } else {
